@@ -6,6 +6,7 @@ tisFromCsv <- function(csvFile,
                        save = F,
                        envir = parent.frame(),
                        naNumber = NULL,
+                       chopNAs = TRUE,
                        tolerance = sqrt(.Machine$double.eps),
                        ...){
   ## csvFile is the path to a csv file with column names across the top.
@@ -16,9 +17,9 @@ tisFromCsv <- function(csvFile,
   ## The function reads in all the data and returns a list of named tis
   ## (Time Indexed Series) objects.  The names of the list are the column
   ## names from the csvFile.
-  ## The naWindow() function is applied to each series to chop off leading and
-  ## trailing NA observations, so the series in the list may not all start and
-  ## end on the same dates.
+  ## If chopNAs is TRUE, the naWindow() function is applied to each series to chop off
+  ## leading and trailing NA observations, so the series in the list may not all start and
+  ## end on the same dates. 
   retList <- list()
   zdf <- read.csv(csvFile, as.is = T, ...)
   zNames <- names(zdf)
@@ -28,7 +29,9 @@ tisFromCsv <- function(csvFile,
   if(all(toupper(zNames) == zNames)) names(zdf) <- tolower(zNames)
   
   zDateStrings <- as.character(zdf[[dateColIndex]])
+  zdf <- zdf[-dateColIndex]
   z <- as.matrix(zdf[,unlist(lapply(zdf, is.numeric)), drop = F])
+
   if(!is.null(naNumber)){
     naSpots <- (1:length(z))[abs(z - naNumber) <= tolerance]
     naSpots <- naSpots[!is.na(naSpots)]
@@ -55,7 +58,11 @@ tisFromCsv <- function(csvFile,
   class(zSeries) <- "tis"
   colnames(zSeries) <- colnames(z)
   
-  retList <- lapply(columns(zSeries), naWindow)
+  if(chopNAs)
+    retList <- lapply(columns(zSeries), naWindow)
+  else
+    retList <- columns(zSeries)
+  
   if(save) assignList(retList, envir = envir)
   gc()
   
